# MGGY-8411-HW1
This package is for currency convertion and calculation.

### Installtion
```
$ pip install xl3335currency
```

### AUDUSD_return
Define the AUDUSD_return class - each instance will store one row from the dataframe.

### GBPEUR_return
Define the GBPEUR_return class - each instance will store one row from the dataframe.

### USDCAD_return
Define the USDCAD_return class - each instance will store one row from the dataframe.

### portfolio
This class defies a nobject for keeping track of our current investments/profits for each currency pair.